************
Installation
************

CubeViz is currently under development.  An alpha testing version can be installed following the instructions _`here <https://github.com/spacetelescope/cubeviz/wiki/Alpha-Testing-Instructions>`_.

Future versions of CubeViz will be installable with _`AstroConda <https://astroconda.readthedocs.io/en/latest/>`_.


